/**
 * This script will convert markers to regions.
 * The original markers are left intact.
 *
 * The script ignores all markers beyond the last event.
 *
 * By John Meyer 12/8/2003
 *
 **/

import System;
import System.IO;
import System.Windows.Forms;
import Sony.Vegas;

var MyRegion    : Region;
var PrevMarker  : Marker;
var RegionStart : Timecode;
var RegionEnd   : Timecode;
var tcOffsetStart : Timecode = new Timecode ("00:00:00:20");
var tcOffsetEnd : Timecode = new Timecode ("00:00:01:05");

try {

  var markerEnum = new Enumerator(Vegas.Project.Markers);  // Start going through all the markers
  PrevMarker = markerEnum.item();                          // Remember first marker

  while (!markerEnum.atEnd()) {                            // Keep going until last marker

    markerEnum.moveNext();                                 // Get next marker

    if (markerEnum.atEnd()) {            // If no more markers (we're almost finished),
      RegionEnd = Vegas.Project.Length - tcOffsetEnd;  // get timecode at end of project
    }

    else {
      RegionEnd = markerEnum.item().Position - tcOffsetEnd;  // Get timecode for current marker
    }


    RegionStart = PrevMarker.Position + tcOffsetStart;   // Regions starts at previous marker.
    var RegionName = PrevMarker.Label;   // Name the region using previous marker's name.

    // The RegionExist function checks if a region already exists at this point.
    if (!RegionExist(RegionStart.ToMilliseconds(),RegionEnd.ToMilliseconds() ) ) {
      MyRegion = new Region(RegionStart,RegionEnd - RegionStart,RegionName);
      Vegas.Project.Regions.Add(MyRegion);     // Add the new region
    }

    if (markerEnum.atEnd()) break;       // If out of markers, quit.

    // If last marker is equal to or beyond the end of the project, stop here.
    if ( Vegas.Project.Length.ToMilliseconds()  <= markerEnum.item().Position.ToMilliseconds() ) {
      break;
    }

    else {
      PrevMarker = markerEnum.item();   // Remember this marker for next loop.
    }

  }

} catch (e) {
    MessageBox.Show(e);
}


function RegionExist(dStart,dLength) : boolean {

  var fmarkerEnum = new Enumerator(Vegas.Project.Regions);

  while (!fmarkerEnum.atEnd()) {
    var fRegion = fmarkerEnum.item();
    var fRegionLength = fRegion.Length.ToMilliseconds();
    var fRegionStart = fRegion.Position.ToMilliseconds();

    if ( (dLength == fRegionLength) && (dStart ==  fRegionStart) ) {
      return 1;
    }
  fmarkerEnum.moveNext();
  }
  return 0;
}