/** 
 * Program:     SetEventLengthAndCrossfade.js
 * Description: This script will set the length of all the selected events
 *              and move the events to crossfade
 *
 * Author: Johnny (Roy) Rofrano  john_rofrano@hotmail.com
 * 
 * Last Updated: 2004-Jul-09 - Initial release
 *
 **/ 
import System.Collections;
import System.Windows.Forms;
import Sony.Vegas; 

// This is the length of each event
var eventLength : Timecode = new Timecode("00:00:05.00");

// This amount the events will be crossfaded
var crossfadeAmount : Timecode = new Timecode("00:00:00.15");

try
{
	// used to count how many events we changed
	var eventCounter = 0;
	
	// Create the dialog box and initialize it
    var dialog = new InputLengthDialog();
    dialog.eventTextBox.Text = eventLength.ToString();
	dialog.crossfadeTextBox.Text = crossfadeAmount.ToString();
	
	// Display the dialog and get the results
    if (DialogResult.OK == dialog.ShowDialog())     
    {
    	eventLength = dialog.getEventLength();
    	crossfadeAmount = dialog.getCrossfadeAmount();
		// step through all tracks
		for (var track in Vegas.Project.Tracks) 
		{
			var trackPosition : Timecode = new Timecode("00:00:00:00");
		
			// Make a copy of the event list because we're going
			// to change it by moving events and that would have
			// undesireable side effects when increasing event length
			var eventList : ArrayList = new ArrayList();
			for (var evnt in track.Events) 
			{
				eventList.Add(evnt);
			}

			// Iterate over the copy of the list
			for (evnt in eventList) 
			{
				if (evnt.Selected)
				{
					// adjust its position on the track
					evnt.Length = eventLength;
					evnt.AdjustStartLength(trackPosition, eventLength, true);
					trackPosition = evnt.End - crossfadeAmount;
					eventCounter++;
				}
			}
		}
	}
	if (eventCounter == 0)
	{
		MessageBox.Show("No Events Selected!","Complete",MessageBoxButtons.OK, MessageBoxIcon.Error);
	}
	else
	{
		MessageBox.Show(eventCounter + " Events modified.", "Complete",MessageBoxButtons.OK, MessageBoxIcon.Information);
	}
}
catch (errorMsg)
{
	MessageBox.Show(errorMsg, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
}

/************************************************
 * Dialog: Input dialog for lengths
 ************************************************/
class InputLengthDialog extends Form
{
	var label2 : Label;
	var groupBox1 : GroupBox;
	var label1 : Label;
	var crossfadeTextBox : TextBox;
	var eventTextBox : TextBox;
	var cancelButton : Button;
	var okButton : Button;
	
	function InputLengthDialog()
	{
		this.okButton = new Button();
		this.cancelButton = new Button();
		this.eventTextBox = new TextBox();
		this.crossfadeTextBox = new TextBox();
		this.label1 = new Label();
		this.groupBox1 = new GroupBox();
		this.label2 = new Label();
		this.groupBox1.SuspendLayout();
		this.SuspendLayout();
		// 
		// okButton
		// 
		this.okButton.DialogResult = System.Windows.Forms.DialogResult.OK;
		this.okButton.Location = new System.Drawing.Point(24, 104);
		this.okButton.Name = "okButton";
		this.okButton.TabIndex = 5;
		this.okButton.Text = "OK";
		// 
		// cancelButton
		// 
		this.cancelButton.DialogResult = System.Windows.Forms.DialogResult.Cancel;
		this.cancelButton.Location = new System.Drawing.Point(120, 104);
		this.cancelButton.Name = "cancelButton";
		this.cancelButton.TabIndex = 6;
		this.cancelButton.Text = "Cancel";
		// 
		// eventTextBox
		// 
		this.eventTextBox.Location = new System.Drawing.Point(120, 17);
		this.eventTextBox.Name = "eventTextBox";
		this.eventTextBox.Size = new System.Drawing.Size(80, 20);
		this.eventTextBox.TabIndex = 0;
		this.eventTextBox.Text = "00:00:00.00";
		// 
		// crossfadeTextBox
		// 
		this.crossfadeTextBox.Location = new System.Drawing.Point(120, 48);
		this.crossfadeTextBox.Name = "crossfadeTextBox";
		this.crossfadeTextBox.Size = new System.Drawing.Size(80, 20);
		this.crossfadeTextBox.TabIndex = 1;
		this.crossfadeTextBox.Text = "00:00:00.00";
		// 
		// label1
		// 
		this.label1.Location = new System.Drawing.Point(8, 24);
		this.label1.Name = "label1";
		this.label1.Size = new System.Drawing.Size(112, 16);
		this.label1.TabIndex = 2;
		this.label1.Text = "Event Length:";
		// 
		// groupBox1
		// 
		this.groupBox1.Controls.Add(this.label2);
		this.groupBox1.Controls.Add(this.label1);
		this.groupBox1.Controls.Add(this.crossfadeTextBox);
		this.groupBox1.Controls.Add(this.eventTextBox);
		this.groupBox1.Location = new System.Drawing.Point(8, 8);
		this.groupBox1.Name = "groupBox1";
		this.groupBox1.Size = new System.Drawing.Size(216, 80);
		this.groupBox1.TabIndex = 4;
		this.groupBox1.TabStop = false;
		// 
		// label2
		// 
		this.label2.Location = new System.Drawing.Point(8, 48);
		this.label2.Name = "label2";
		this.label2.Size = new System.Drawing.Size(112, 24);
		this.label2.TabIndex = 3;
		this.label2.Text = "Crossfade Amount:";
		// 
		// LengthForm
		// 
		this.AcceptButton = this.okButton;
		this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
		this.CancelButton = this.cancelButton;
		this.ClientSize = new System.Drawing.Size(232, 142);
		this.ControlBox = false;
		this.Controls.Add(this.cancelButton);
		this.Controls.Add(this.okButton);
		this.Controls.Add(this.groupBox1);
		this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
		this.MinimizeBox = false;
		this.Name = "LengthForm";
		this.StartPosition = FormStartPosition.CenterScreen;
		this.Text = "Set Lengths";
		this.groupBox1.ResumeLayout(false);
		this.ResumeLayout(false);
	}

	// Returns the event length as a timecode
	function getEventLength()
	{
		return new Timecode(eventTextBox.Text);
	}

	// Returns the corssfade amount as a timecode
	function getCrossfadeAmount()
	{
		return new Timecode(crossfadeTextBox.Text);
	}

}
